@@ -45,9 +45,14 @@ def read(fp):
     """Deserialize an OOPS from a bson or rfc822 message.
     
     The whole file is read regardless of the OOPS format.
+
+    :raises IOError: If the file has no content.
     """
     # Deal with no-rewindable file pointers.
     content = fp.read()
+    if len(content) == 0:
+        # This OOPS has no content
+        raise IOError("Empty OOPS Report")
     try:
         return serializer_bson.read(StringIO(content))
     except KeyError:
